<?php

/*
Plugin Name: BuddyPress Maps for Profile
Plugin URI:  http://dev.benoitgreant.be/2010/02/01/buddypress-classifieds
Description: This component adds classifieds to your BuddyPress installation.
Version: 0.1
Revision Date: february 13, 2010
Requires at least: WPMU 2.9.1.1, WPMU 2.9.1, BuddyPress 1.2-rc
Tested up to: WPMU 2.9.1.1, WPMU 2.9.1, BuddyPress 1.2-rc
License: (Classifieds: GNU General Public License 2.0 (GPL) http://www.gnu.org/licenses/gpl.html)
Author: G.Breant
Author URI: http://dev.benoitgreant.be
Site Wide Only: true
*/

/*** Make sure BuddyPress is loaded ********************************/
if ( !function_exists( 'bp_core_install' ) ) {
	require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
	if ( is_plugin_active( 'buddypress/bp-loader.php' ) )
		require_once ( WP_PLUGIN_DIR . '/buddypress/bp-loader.php' );
	else
		return;
}
/*******************************************************************/


function bp_maps_profile_setup_globals() {
	global $bp;
	
	$options_defaults=array(
		'groups_maps'=>true
	);

	$custom_options = get_site_option( 'bp_maps_profile_options');

	$bp->maps_profile->options = wp_parse_args($custom_options, $options_defaults );
	
}


///ADMIN///
function bp_maps_profile_admin_tab() {
	?>
	<li><a href="#profile-map"><?php _e('Profile map', 'bp-maps-profile') ;?></a></li>
	<?php
}
function bp_maps_profile_is_enabled() {
	global $bp;
	$options=$bp->maps_profile->options;
	if (($options['group_id']) && ($options['field_after']))
		return true;
	return false;
}
function bp_maps_profile_admin_div() {
	global $bp;
	
	//HANDLING INSTALL | START
	$required_options=array('group_id','field_after');
	$install_steps=count($required_options);
	
	$options=$bp->maps_profile->options;
	
	if ($required_options) {
		$current_step=1;
		if ($options) {
			foreach ($options as $key=>$value) {
				if (in_array($key,$required_options)) {
					$current_step++;
				}
			}
			if ($current_step>$install_steps) unset($required_options);
		}
	}

	
	if (!$required_options) {
		$save_text = __('Save Settings', 'buddypress');
	}else{
		$save_text = __('Install', 'buddypress').' '.$current_step.'/'.$install_steps;
	}
	
	//HANDLING INSTALL | STOP


	$groups_args = array(
		'user_id'=>false,
		'fetch_fields'=>false,
	);
	
	if ($options['group_id']) $groups_args['fetch_fields']=true;


	$groups = BP_XProfile_Group::get($groups_args);

?>
<div id="profile-map">

	<h2><?php _e('Profile map', 'bp-maps-profile') ;?></h2>
	<form action="#profile-map" name="bp-maps-profile-options" id="bp-maps-profile-options" method="post">	
		<table class="form-table">
			<tr valign="top">
				<th scope="row"><label for="bp_maps_profile_group_id"><?php _e('Profile group to use', 'bp-maps') ?></label></th>
				<td>
				<?php
				foreach ($groups as $group) {
					if ($group->id==$options['group_id']) $checked=" CHECKED";
					
					echo'<input class="required" type="radio" value="'.$group->id.'" name="bp_maps_profile_group_id"'.$checked.'>'.$group->name;
					
					unset($checked);
				}
				?>
				</td>
			</tr>
			<?php if ($options['group_id']) {?>
				<tr valign="top">
					<th scope="row"><label for="bp_maps_profile_field_after"><?php _e('Field after which the map will be inserted', 'bp-maps') ?></label></th>
					<td>
					<?php
					foreach ($groups as $group) {
						echo "<div>";
						if ($group->id!=$options['group_id']) continue;
						if (!$group->fields) continue;
						
						foreach ($group->fields as $field) {

							if ($field->id==$options['field_after']) $checked=" CHECKED";
							
							echo'<input type="radio" value="'.$field->id.'" name="bp_maps_profile_field_after"'.$checked.'>'.$field->name;
							
							unset($checked);

						}
						
						echo "<div>";
					}
					?>
					</td>
				</tr>
				<?php }?>
				<?php if (!$required_options) {?>
				<tr valign="top">
					<th scope="row"><label for="bp_maps_profile_fields"><?php _e('Fields used to suggest location', 'bp-maps') ?></label></th>
					<td>
					<?php
					foreach ($groups as $group) {
						echo "<div>";
						if ($group->id!=$options['group_id']) continue;
						if (!$group->fields) continue;

						
						foreach ($group->fields as $field) {

							if (($options['fields']) && (in_array($field->id,$options['fields']))) $checked=" CHECKED";
							
							echo'<input type="checkbox" value="'.$field->id.'" name="bp_maps_profile_fields[]"'.$checked.'>'.$field->name;
							
							unset($checked);

						}
						
						echo "<div>";
					}
					?>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label for="bp_groups_maps"><?php _e('Enable maps for groups', 'bp-maps-profile') ?></label></th>
					<td>
					<?php
					if ($options['groups_maps']) $checked=" CHECKED";
					echo'<input type="checkbox" value="1" name="bp_groups_maps"'.$checked.'>';
					?>
					</td>
				</tr>
			<?php }?>
		</table>
		<p id="bp-maps-profile-submit" class="submit">
			<input type="hidden" name="action" value="bp-maps-profile" />
			<input class="button-primary" type="submit" name="submit" value="<?php echo $save_text ?>"/>
			<input type="checkbox" value="1" name="bp_maps_profile_reset"><?php _e('Reset Options','bp-maps');?>
		</p>
		<?php wp_nonce_field('bp-maps-profile-options') ?>
	</form>
</div>
<?php
}

function bp_maps_profile_admin_save() {

	if ($_POST['action']!='bp-maps-profile') return false;

	check_admin_referer('bp-maps-profile-options');
	
	global $errors;
	global $bp;
	
	if (!$errors)
		$errors = new WP_Error();
	
	if ($_POST['bp_maps_profile_reset']) {

		if (!delete_site_option('bp_maps_profile_options')) {
			$errors->add('bp_maps_profile_reset',__( 'Error while trying to reset options.', 'maps' ));
		}
		return ;
	}
	
	

	
	
	$options=get_site_option( 'bp_maps_profile_options');
	$_options=array();
	
	//group ID
	if (!$_POST['bp_maps_profile_group_id']) {
		$errors->add('bp_maps_profile_group_id',__( 'You have to choose a group first', 'bp-maps-profile' ));
		return false;
	}
	$_options['group_id']=$_POST['bp_maps_profile_group_id'];
	
	//fields after
	if (!empty($_POST['bp_maps_profile_field_after']))
		$_options['field_after']=$_POST['bp_maps_profile_field_after'];
	
	//fields IDs
	if (!empty($_POST['bp_maps_profile_fields']))
		$_options['fields']=$_POST['bp_maps_profile_fields'];
	
	//group maps
	$_options['groups_maps']=$_POST['bp_groups_maps'];
	

	$options = wp_parse_args( $_options, $options ); //changes full array options with updated values

	if (update_site_option( 'bp_maps_profile_options', $options ))
		$message = __('Settings saved','maps');
}

///ADMIN | END ///

function bp_edit_profile_map() {
	global $field;
	global $bp;

	
	
	if ($field->group_id!=$bp->maps_profile->options['group_id']) return false;
	
	if ($field->id!=$bp->maps_profile->options['field_after']) return false;

	global $wpdb;

	///QUERY
	$user_id=$bp->displayed_user->id;
	$type='member_profile';

	//FETCH THE MARKERS WE WANT
	$query = $wpdb->prepare( "SELECT id FROM `{$bp->maps->table_name_markers}` mk WHERE user_id={$user_id} AND type='{$type}'");

	$markers_ids = $wpdb->get_col($query );

	$args=array(
		'enable_desc'=>true,
		'type'=>'member_profile',
		'markers_max'=>5
	);
	
	if (bp_is_profile_edit())
		$args['editable']=true;

	//BUILD THE MAP
	$map = new Bp_Map($markers_ids,$args);
	
	//SHOW MAPS
	if (!bp_is_profile_edit()) {
			   ?>
		<tr>
			<td class="label">
				<?php _e('Map Location','bp-maps');?>
			</td>

			<td class="data">
				<?php bp_maps_map_html($map);?>
			</td>

		</tr>
		<?php
	}else {
		echo'<label>'.__('Map Location','bp-maps').'</label>';
		bp_maps_map_html($map);
	}

}

function bp_maps_profile_add_map_js($js,$map) {
	global $bp;
	
	$fields = $bp->maps_profile->options['fields'];
	
	$js[]="var map_profile_fields=new Array(".implode(',',$fields).");";	
	
	return $js;
}

///DISPLAY USER'S INFORMATION AS INFOWINDOW
function bp_maps_profile_get_marker_content($content,$marker) {

	$user_id = $marker->user_id;

	$content.=bp_core_fetch_avatar( array( 'item_id' => $user_id) );
	
	$content='<h3 class="fn"><a href="'.bp_core_get_user_domain($user_id).'">'.bp_core_get_username($user_id).'</a> <span class="highlight">@'.bp_core_get_username($user_id,true).'</h3>';
	
	$content.='<span class="activity">'.bp_last_activity( $user_id,false).'</span>';
	
	if ( function_exists( 'bp_activity_latest_update' ) ) : 
		$content.= '<div id="latest-update">'.bp_get_activity_latest_update( $user_id ).'</div>';
	endif;
	
	return $content;
	
}



function bp_maps_profile_print_scripts($js) {
	if (!bp_is_user_profile()) return false;
	if (!bp_is_profile_edit()) return false;

	wp_enqueue_script('bp-maps-profile',BP_MAPS_PLUGIN_URL . '/_inc/js/bp-maps-profile.js', array('jquery'),BP_MAPS_VERSION);
	
}

add_action('wp_print_scripts','bp_maps_profile_print_scripts');



function bp_maps_profile_init() {
	global $bp;

	add_action( 'bp_maps_admin_save', 'bp_maps_profile_admin_save');
	add_action( 'bp_maps_admin_tabs','bp_maps_profile_admin_tab');
	add_action( 'bp_maps_admin_div','bp_maps_profile_admin_div');
	
	//groups maps
	if ($bp->maps_profile->options['groups_maps']) {
		require_once ( BP_MAPS_PLUGIN_DIR . '/bp-maps-groups.php' );
	}
	
	
	
	if (!bp_is_user_profile()) return false;

	//IF USERGROUP CHECK
	add_action('bp_custom_profile_edit_fields','bp_edit_profile_map');
	add_action('bp_profile_field_item','bp_edit_profile_map');
	
	add_filter('bp_maps_get_map_js','bp_maps_profile_add_map_js',10,2);
	add_filter('bp_maps_get_marker_content','bp_maps_profile_get_marker_content',10,2);
	
	bp_maps_head_init();

}


add_action( 'bp_maps_init', 'bp_maps_profile_init');
add_action( 'plugins_loaded', 'bp_maps_profile_setup_globals', 5 );
add_action( 'admin_menu', 'bp_maps_profile_setup_globals', 2 );



?>